@@ -22,7 +22,7 @@ import functools
 import tensorflow as tf
 
 
-def _shard(ds, input_pipeline_context):
+def shard(ds, input_pipeline_context):
   # The dataset is always sharded by number of hosts.
   # num_input_pipelines is the number of hosts rather than number of cores.
   if (input_pipeline_context and
@@ -63,7 +63,8 @@ class DataLoader(object):
                   is_training=False,
                   shuffle=False,
                   input_pipeline_context=None,
-                  preprocess=None):
+                  preprocess=None,
+                  drop_remainder=False):
     """Generate a shared and batched tf.data.Dataset for training/evaluation.
 
     Args:
@@ -76,16 +77,17 @@ class DataLoader(object):
         among multiple workers when distribution strategy is used.
       preprocess: A function taking three arguments in order, feature, label and
         boolean is_training.
+      drop_remainder: boolean, whether the finaly batch drops remainder.
 
     Returns:
       A TF dataset ready to be consumed by Keras model.
     """
     ds = self._dataset
-    ds = _shard(ds, input_pipeline_context)
+    ds = shard(ds, input_pipeline_context)
 
     if preprocess:
       preprocess = functools.partial(preprocess, is_training=is_training)
-      ds = ds.map(preprocess, num_parallel_calls=tf.data.experimental.AUTOTUNE)
+      ds = ds.map(preprocess, num_parallel_calls=tf.data.AUTOTUNE)
 
     if is_training:
       if shuffle:
@@ -100,8 +102,8 @@ class DataLoader(object):
         ds = ds.shuffle(buffer_size=min(self._size, buffer_size))
       ds = ds.repeat()
 
-    ds = ds.batch(batch_size)
-    ds = ds.prefetch(tf.data.experimental.AUTOTUNE)
+    ds = ds.batch(batch_size, drop_remainder=drop_remainder)
+    ds = ds.prefetch(tf.data.AUTOTUNE)
     # TODO(b/171449557): Consider converting ds to distributed ds here.
     return ds
 
