@@ -126,7 +126,7 @@ class CustomModel(abc.ABC):
              export_dir,
              tflite_filename='model.tflite',
              label_filename='labels.txt',
-             vocab_filename='vocab',
+             vocab_filename='vocab.txt',
              saved_model_filename='saved_model',
              tfjs_folder_name='tfjs',
              export_format=None,
@@ -160,7 +160,10 @@ class CustomModel(abc.ABC):
       tflite_filepath = os.path.join(export_dir, tflite_filename)
       export_tflite_kwargs, kwargs = _get_params(self._export_tflite, **kwargs)
       self._export_tflite(tflite_filepath, **export_tflite_kwargs)
+      tf.compat.v1.logging.info(
+          'TensorFlow Lite model exported successfully: %s' % tflite_filepath)
     else:
+      tflite_filepath = None
       with_metadata = False
 
     if ExportFormat.SAVED_MODEL in export_format:
@@ -172,7 +175,7 @@ class CustomModel(abc.ABC):
 
     if ExportFormat.TFJS in export_format:
       tfjs_output_path = os.path.join(export_dir, tfjs_folder_name)
-      self._export_tfjs(tfjs_output_path)
+      self._export_tfjs(tfjs_output_path, tflite_filepath=tflite_filepath)
 
     if ExportFormat.VOCAB in export_format:
       if with_metadata:
@@ -232,13 +235,16 @@ class CustomModel(abc.ABC):
     """
     model_util.export_tflite(self.model, tflite_filepath, quantization_config)
 
-  def _export_tfjs(self, tfjs_filepath):
+  def _export_tfjs(self, tfjs_filepath, tflite_filepath=None, **kwargs):
     """Converts the retrained model to tflite format.
 
     Args:
       tfjs_filepath: File path to save tflite model.
+      tflite_filepath: File path to existing tflite model.
+      **kwargs: Additional kwargs.
     """
-    model_util.export_tfjs(self.model, tfjs_filepath)
+    model_util.export_tfjs(
+        self.model, tfjs_filepath, tflite_filepath=tflite_filepath, **kwargs)
 
   def _keras_callbacks(self, model_dir):
     """Returns a list of default keras callbacks for `model.fit`."""
