@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""QuestionAnswer class."""
+"""APIs to train a model that can answer questions based on a predefined text."""
 
 from __future__ import absolute_import
 from __future__ import division
@@ -23,6 +23,7 @@ import tempfile
 import tensorflow as tf
 
 from tensorflow_examples.lite.model_maker.core import compat
+from tensorflow_examples.lite.model_maker.core.api import mm_export
 from tensorflow_examples.lite.model_maker.core.export_format import ExportFormat
 from tensorflow_examples.lite.model_maker.core.task import custom_model
 from tensorflow_examples.lite.model_maker.core.task import model_spec as ms
@@ -30,43 +31,8 @@ from tensorflow_examples.lite.model_maker.core.task import model_util
 from tensorflow_examples.lite.model_maker.core.task.metadata_writers.bert.question_answerer import metadata_writer_for_bert_question_answerer as metadata_writer
 
 
-def create(train_data,
-           model_spec,
-           batch_size=None,
-           epochs=2,
-           shuffle=False,
-           do_train=True):
-  """Loads data and train the model for question answer.
-
-  Args:
-    train_data: Training data.
-    model_spec: Specification for the model.
-    batch_size: Batch size for training.
-    epochs: Number of epochs for training.
-    shuffle: Whether the data should be shuffled.
-    do_train: Whether to run training.
-
-  Returns:
-    object of QuestionAnswer class.
-  """
-  model_spec = ms.get(model_spec)
-  if compat.get_tf_behavior() not in model_spec.compat_tf_versions:
-    raise ValueError('Incompatible versions. Expect {}, but got {}.'.format(
-        model_spec.compat_tf_versions, compat.get_tf_behavior()))
-
-  model = QuestionAnswer(model_spec, shuffle=shuffle)
-
-  if do_train:
-    tf.compat.v1.logging.info('Retraining the models...')
-    model.train(train_data, epochs, batch_size)
-  else:
-    model.create_model()
-
-  return model
-
-
 def _get_model_info(model_spec, vocab_file):
-  """Gets the specific info for the image model."""
+  """Gets the specific info for the question answer model."""
   return metadata_writer.QuestionAnswererInfo(
       name=model_spec.name + ' Question and Answerer',
       version='v1',
@@ -82,6 +48,7 @@ def _get_model_info(model_spec, vocab_file):
       vocab_file=vocab_file)
 
 
+@mm_export('question_answer.QuestionAnswer')
 class QuestionAnswer(custom_model.CustomModel):
   """QuestionAnswer class for inference and exporting to tflite."""
 
@@ -180,16 +147,25 @@ class QuestionAnswer(custom_model.CustomModel):
 
   def _export_tflite(self,
                      tflite_filepath,
-                     quantization_config=None,
-                     with_metadata=True):
+                     quantization_config='default',
+                     with_metadata=True,
+                     export_metadata_json_file=False):
     """Converts the retrained model to tflite format and saves it.
 
     Args:
       tflite_filepath: File path to save tflite model.
-      quantization_config: Configuration for post-training quantization.
-      with_metadata: Whether the output tflite model contains metadata. If True,
-        Exports metadata in json file as well.
+      quantization_config: Configuration for post-training quantization. If
+        'default', sets the `quantization_config` by default according to
+        `self.model_spec`. If None, exports the float tflite model without
+        quantization.
+      with_metadata: Whether the output tflite model contains metadata.
+      export_metadata_json_file: Whether to export metadata in json file. If
+        True, export the metadata in the same directory as tflite model.Used
+        only if `with_metadata` is True.
     """
+    if quantization_config == 'default':
+      quantization_config = self.model_spec.get_default_quantization_config()
+
     # Sets batch size from None to 1 when converting to tflite.
     model_util.set_batch_size(self.model, batch_size=1)
     model_util.export_tflite(self.model, tflite_filepath, quantization_config,
@@ -207,4 +183,45 @@ class QuestionAnswer(custom_model.CustomModel):
         export_dir = os.path.dirname(tflite_filepath)
         populator = metadata_writer.MetadataPopulatorForBertQuestionAndAnswer(
             tflite_filepath, export_dir, model_info)
-        populator.populate()
+        populator.populate(export_metadata_json_file)
+
+  @classmethod
+  def create(cls,
+             train_data,
+             model_spec,
+             batch_size=None,
+             epochs=2,
+             shuffle=False,
+             do_train=True):
+    """Loads data and train the model for question answer.
+
+    Args:
+      train_data: Training data.
+      model_spec: Specification for the model.
+      batch_size: Batch size for training.
+      epochs: Number of epochs for training.
+      shuffle: Whether the data should be shuffled.
+      do_train: Whether to run training.
+
+    Returns:
+      An instance based on QuestionAnswer.
+    """
+    model_spec = ms.get(model_spec)
+    if compat.get_tf_behavior() not in model_spec.compat_tf_versions:
+      raise ValueError('Incompatible versions. Expect {}, but got {}.'.format(
+          model_spec.compat_tf_versions, compat.get_tf_behavior()))
+
+    model = cls(model_spec, shuffle=shuffle)
+
+    if do_train:
+      tf.compat.v1.logging.info('Retraining the models...')
+      model.train(train_data, epochs, batch_size)
+    else:
+      model.create_model()
+
+    return model
+
+
+# Shortcut function.
+create = QuestionAnswer.create
+mm_export('question_answer.create').export_constant(__name__, 'create')
